﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet id="stylesheet" version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:template match="/">
		<html>
			<head>
				<title>Artist Spotlight: <xsl:value-of select="Spotlight/Artist/Name"/></title>
				<style>
					<!--Scrollbar size-->
					::-webkit-scrollbar {
						width: 5px;
						height: 10px;
					}

					<!--Scrollbar track-->
					::-webkit-scrollbar-track {
					   background: #f1f1f1; 
					}

					<!--Scrollbar handle-->
					::-webkit-scrollbar-thumb {
					   background: #909090;
					}

					<!--Scrollbar handle (hover)-->
					::-webkit-scrollbar-thumb:hover {
						background: #505050;
					}

					a:focus {
						outline: 3px solid blue;
					}
          
          a:focus.no-outline {
						outline: none;
          }
				</style>
			</head>
			<body style="background-color: {Spotlight/Artist/@backColor}; color: {Spotlight/Artist/@textColor}; font-family: system-ui; font-weight: bold; margin: 10px;">
				<div id="grid_main" role="grid">
					<!--Artist name and Playing Now button-->
					<div role="row" aria-rowindex="1" style="font-size: x-large;">
						<span role="gridcell" aria-colindex="1">
							<a id="link_main" tabindex="0" href="{Spotlight/Artist/Bios/Bio/@srcURL}" title="{Spotlight/Artist/Bios/Bio/@srcName}" style="text-decoration:none; color:inherit">
								<xsl:value-of select="Spotlight/Artist/Name"/>
								<!--(<xsl:value-of select="Spotlight/Artist/Years"/>)-->
							</a>
						</span>
						<span role="gridcell" aria-colindex="2">
							<a href="http://internal/MCWS/v1/Spotlight/GetPage?Type=pn_menu&amp;Name=1" title ="Spotlight: Playing Now" style="display: inline-block; float: right;">
								<img src="https://files.jriver-cdn.com/spotlight/NoThumbAudio.png" style="height:30px"/>
							</a>
						</span>
					</div>

					<!--Artist images (horizontal list)-->
					<div style="overflow-x: clip;">
						<span style="display: flex;">
							<xsl:for-each select="Spotlight/Artist/Images/Image">
								<!--Have to do the <img> manually with text because attribute text is always escaped-->
								<xsl:text disable-output-escaping="yes">&lt;img src="</xsl:text>
								<xsl:value-of disable-output-escaping="yes" select="." />
								<xsl:text disable-output-escaping="yes">" style="height:168px; object-fit: cover" /&gt;</xsl:text>
							</xsl:for-each>
						</span>
					</div>

					<!--Albums list (horizontal thumbnails)-->
					<div style="padding-left: 0px; padding-top: 5px;">Albums</div>
					<div role="row" aria-rowindex="2" style="font-size: small; display: flex; overflow-x: auto">
						<xsl:for-each select="Spotlight/Artist/Albums/Album[Year!='']">		<!--Only show if it has a year-->
							<xsl:sort select="Year"/>  <!--Sort by year-->
							<span style="vertical-align: top; text-align: center; margin: 10px; display: inline-block; width: 112px; font-weight: normal">
								<span role="gridcell" aria-colindex="{position()}" style="position: relative">
									<a href="{./Link}" title="Google: {./AlbumName}">
										<xsl:choose>
											<xsl:when test="./AlbumArt">
												<img src="{./AlbumArt}" style="width:112px; height:112px; border-radius:5px" />
											</xsl:when>
											<xsl:otherwise>
												<img src="{/Spotlight/Artist/MissingThumbImage}" style="width:107px; height:107px; border-radius:5px; border-color:darkgray; border-style:none;" />
											</xsl:otherwise>
										</xsl:choose>
									</a>

									<xsl:if test="./PlayURL">
										<a href="{./PlayURL}" title="Play from library" style="position: absolute; top: -5; left:-1">
											<img src="https://files.jriver-cdn.com/spotlight/PlayOverlay.png" style="height:20px"></img>
										</a>
									</xsl:if>
								</span>
								<span style="display: block; font-weight: bold; margin-top: 4px">
									<xsl:value-of disable-output-escaping="yes" select="./AlbumName"/>
								</span>
								<span style="display: block;">
									<xsl:value-of select="./Year"/>
								</span>
							</span>
						</xsl:for-each>
					</div>

					<!--Similar Artists (horizontal thumbnails)-->
					<div style="padding-left: 0px; padding-top: 5px;">Related Artists</div>
					<div role="row" aria-rowindex="3" style="font-size: small; display: flex; overflow-x: auto">
						<xsl:for-each select="Spotlight/Artist/SimilarArtists/SimilarArtist[ArtistImage!='']">
							<span style="vertical-align: top; text-align: center; margin: 10px; display: inline-block; width: 112px; font-weight: normal">
								<span role="gridcell" aria-colindex="{position()}" style="display: block">
									<!--Have to do the <a> manually with text because attribute text is always escaped-->
									<xsl:text disable-output-escaping="yes">&lt;a href="</xsl:text>
									<xsl:value-of  disable-output-escaping="yes" select="./SimilarLink" />
									<xsl:text disable-output-escaping="yes">" title="Spotlight: </xsl:text>
									<xsl:value-of disable-output-escaping="yes" select="./ArtistName" />
									<xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
									<xsl:choose>
										<xsl:when test="./ArtistImage">
											<img src="{./ArtistImage}" style="width:112px; height:112px; object-fit:scale-down; border-radius:5px" />
										</xsl:when>
										<xsl:otherwise>
											<img src="{/Spotlight/Artist/MissingThumbImage}" style="width:107px; height:107px; border-radius:5px; border-color:darkgray; border-style:none;" />
										</xsl:otherwise>
									</xsl:choose>
									<xsl:text disable-output-escaping="yes">&lt;/a&gt;</xsl:text>
								</span>
								<span style="display: block; font-weight: bold; margin-top: 4px">
									<xsl:value-of disable-output-escaping="yes" select="./ArtistName"/>
								</span>
							</span>
						</xsl:for-each>
					</div>

					<!--Bios-->
					<!--<div style="margin: 20px;"/>-->
					<xsl:for-each select="Spotlight/Artist/Bios/Bio">
						<div style="margin: 0px;">
							<!--<div style="padding-top: 5px;">
								About
								--><!--<img src="{@sourceIcon}" height="20px"/>--><!--
							</div>-->
							<div role="row" aria-rowindex="4" style="font-size: medium; font-weight: normal; padding-top: 5px;">
								<xsl:value-of select="."/>
									<span role="gridcell" aria-colindex="1" style="margin-left: 5px; font-size:small;">
										<a href="{@srcURL}" style="color:inherit">
											<xsl:value-of select="@srcName"/>
										</a>
									</span>
								<xsl:if test="@srcDonate">
									<span role="gridcell" aria-colindex="2" style="font-size:small;">
										|  <a href="{@srcDonate}" style="color:inherit">Donate</a>
									</span>
								</xsl:if>
							</div>
						</div>
					</xsl:for-each>

					<!--Date updated-->
					<div role="row" aria-rowindex="5" style="padding-top:5px;">
						<div role="gridcell" aria-colindex="1" style="text-align:center; font-size:x-small; font-weight:normal">Updated <xsl:value-of select="Spotlight/Artist/@dateGenerated"/>  |  <a href="{Spotlight/Artist/UpdateLink}" title="Update data" style="font-size:x-small; font-weight:normal; color:inherit">Update</a></div>
					</div>
				</div>

				<!--For remote/keyboard navigation-->
				<script src="https://files.jriver-cdn.com/spotlight/spotlight_nav_kb.js"/>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
